@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use base qw(Text::Livedoor::Wiki::Plugin::Inline);
 
-__PACKAGE__->regex(q{\(\(([^\)]*)\)\)});
+__PACKAGE__->regex(q{\(\(((?:(?<!\)\)).)*)\)\)});
 __PACKAGE__->n_args(1);
 
 sub process {
